discoveredProperties property
Properties received during discoverServices.
Usually use properties, which resolves against the latest known services cache.
Implementation
final BleCharacteristicProperties discoveredProperties;
Properties received during discoverServices.
Usually use properties, which resolves against the latest known services cache.
final BleCharacteristicProperties discoveredProperties;