BleCharacteristicProperties class final

Constructors

BleCharacteristicProperties({bool broadcast = false, bool read = false, bool writeWithoutResponse = false, bool write = false, bool notify = false, bool indicate = false, bool authenticatedSignedWrites = false, bool extendedProperties = false})
const
BleCharacteristicProperties.fromMap(Map map)
factory

Properties

authenticatedSignedWrites bool
final
broadcast bool
final
extendedProperties bool
final
hashCode int
The hash code for this object.
no setterinherited
indicate bool
final
notify bool
final
read bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
write bool
final
writeWithoutResponse bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited