BleCharacteristicWriteEvent class final

Constructors

BleCharacteristicWriteEvent({required BleRemoteId remoteId, required String serviceUuid, required String characteristicUuid, required int instanceId, required bool success, required int errorCode, required String errorString, String? primaryServiceUuid})
const
BleCharacteristicWriteEvent.fromMap(Map map)
factory

Properties

characteristicUuid → String
final
errorCode → int
final
errorString → String
final
hashCode → int
The hash code for this object.
no setterinherited
instanceId → int
final
primaryServiceUuid → String?
final
remoteId → BleRemoteId
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceUuid → String
final
success → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited