BleConnectionEvent class final

Constructors

BleConnectionEvent({required BleRemoteId remoteId, required BleConnectionState connectionState, int? disconnectReasonCode, String? disconnectReasonString})
const
BleConnectionEvent.fromMap(Map map)
factory

Properties

connectionState BleConnectionState
final
disconnectReasonCode int?
final
disconnectReasonString String?
final
hashCode int
The hash code for this object.
no setterinherited
remoteId BleRemoteId
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited