BleMtuEvent class final

Constructors

BleMtuEvent({required BleRemoteId remoteId, required int mtu, required bool success, required int errorCode, required String errorString})
const
BleMtuEvent.fromMap(Map map)
factory

Properties

errorCode int
final
errorString String
final
hashCode int
The hash code for this object.
no setterinherited
mtu int
final
remoteId BleRemoteId
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited