Ble class final

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

adapterState Stream<BleAdapterState>
no setter
adapterStateNow BleAdapterState
no setter
connectedDevices List<BleDevice>
no setter
connectedDevicesChanged Stream<List<BleDevice>>
no setter
isSupported Future<bool>
no setter

Static Methods

refreshAdapterState() Future<BleAdapterState>
scan({Duration? timeout}) Stream<BleScanResult>
Scans for nearby BLE devices until the listener cancels the stream.