BleMethodChannel class final
- Inheritance
-
- Object
- PlatformInterface
- BlePlatform
- BleMethodChannel
Constructors
Properties
-
adapterStateChanged
→ Stream<
BleAdapterState> -
no setteroverride
- adapterStateNow → BleAdapterState
-
no setteroverride
-
characteristicWritten
→ Stream<
BleCharacteristicWriteEvent> -
no setteroverride
-
connectedDevices
→ List<
BleDevice> -
no setteroverride
-
connectionState
→ Stream<
BleConnectionEvent> -
no setteroverride
-
discoveredServices
→ Stream<
BleDiscoveredServicesEvent> -
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
final
-
mtuChanged
→ Stream<
BleMtuEvent> -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
advName(
BleRemoteId remoteId) → String -
override
-
characteristicProperties(
BleCharacteristic characteristic) → BleCharacteristicProperties? -
override
-
connect(
String remoteId) → Future< bool> -
override
-
disconnect(
String remoteId) → Future< bool> -
override
-
discoverServices(
String remoteId) → Future< bool> -
override
-
getAdapterState(
) → Future< BleAdapterState> -
override
-
isDeviceConnected(
BleRemoteId remoteId) → bool -
override
-
isSupported(
) → Future< bool> -
override
-
mtuNow(
BleRemoteId remoteId) → int -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
platformName(
BleRemoteId remoteId) → String -
override
-
requestMtu(
{required String remoteId, required int mtu}) → Future< bool> -
override
-
scan(
{Duration? timeout}) → Stream< BleScanResult> -
override
-
servicesForDevice(
BleRemoteId remoteId) → List< BleService> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
writeCharacteristic(
{required String remoteId, required String serviceUuid, required String characteristicUuid, required int instanceId, required List< int> value, String? primaryServiceUuid, bool withoutResponse = false}) → Future<bool> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited