BleAdvertisementData class final
Constructors
-
BleAdvertisementData({required bool connectable, String advName = '', int? txPowerLevel, int? appearance, Map<
int, List< manufacturerData = const <int, List<int>>{}, Map<int> >String, List< serviceData = const <String, List<int>>{}, List<int> >String> serviceUuids = const <String>[]}) -
const
- BleAdvertisementData.fromMap(Map map)
-
factory
Properties
- advName → String
-
final
- appearance → int?
-
final
- connectable → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
manufacturerData
→ Map<
int, List< int> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serviceData
→ Map<
String, List< int> > -
final
-
serviceUuids
→ List<
String> -
final
- txPowerLevel → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited