BleCharacteristic class final

Annotations

Constructors

BleCharacteristic({required BleRemoteId remoteId, required String serviceUuid, required String characteristicUuid, required int instanceId, required BleCharacteristicProperties discoveredProperties, String? primaryServiceUuid})
const
BleCharacteristic.fromMap(Map map)
factory

Properties

characteristicUuid String
final
device BleDevice
no setter
discoveredProperties BleCharacteristicProperties
Properties received during discoverServices.
final
hashCode int
The hash code for this object.
no setteroverride
instanceId int
final
primaryServiceUuid String?
final
properties BleCharacteristicProperties
no setter
remoteId BleRemoteId
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceUuid String
final
uuid String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
write(List<int> value, {bool withoutResponse = false, int timeout = 15}) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
override