BleDevice class final

Annotations

Constructors

BleDevice({required BleRemoteId remoteId, String? platformName, String? advName})
const
BleDevice.fromId(String remoteId, {String? platformName, String? advName})

Properties

advName String
no setter
connectionState Stream<BleConnectionState>
no setter
hashCode int
The hash code for this object.
no setteroverride
isConnected bool
no setter
isDisconnected bool
no setter
mtu Stream<int>
no setter
mtuNow int
no setter
platformName String
no setter
remoteId BleRemoteId
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
servicesList List<BleService>
no setter

Methods

connect({Duration timeout = const Duration(seconds: 35), int? mtu = 512}) Future<void>
disconnect({int timeout = 35}) Future<void>
discoverServices({int timeout = 15}) Future<List<BleService>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestMtu(int desiredMtu, {int timeout = 15}) Future<int>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override