BleScanResult class final

Annotations

Constructors

BleScanResult({required BleDevice device, required BleAdvertisementData advertisementData, required int rssi})
const
BleScanResult.fromMap(Map map)
factory

Properties

advertisementData BleAdvertisementData
final
device BleDevice
final
hashCode int
The hash code for this object.
no setteroverride
rssi int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override