BleService class final
- Annotations
Constructors
-
BleService({required BleRemoteId remoteId, required String serviceUuid, required List<
BleCharacteristic> characteristics, String? primaryServiceUuid}) -
const
- BleService.fromMap(Map map)
-
factory
Properties
-
characteristics
→ List<
BleCharacteristic> -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isPrimary → bool
-
no setter
- isSecondary → bool
-
no setter
- primaryServiceUuid → String?
-
final
- remoteId → BleRemoteId
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceUuid → String
-
final
- uuid → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override