BlePlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • BlePlatform
Implementers

Constructors

BlePlatform()

Properties

adapterStateChanged Stream<BleAdapterState>
no setter
adapterStateNow BleAdapterState
no setter
characteristicWritten Stream<BleCharacteristicWriteEvent>
no setter
connectedDevices List<BleDevice>
no setter
connectionState Stream<BleConnectionEvent>
no setter
discoveredServices Stream<BleDiscoveredServicesEvent>
no setter
hashCode int
The hash code for this object.
no setterinherited
mtuChanged Stream<BleMtuEvent>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

advName(BleRemoteId remoteId) String
characteristicProperties(BleCharacteristic characteristic) BleCharacteristicProperties?
connect(String remoteId) Future<bool>
disconnect(String remoteId) Future<bool>
discoverServices(String remoteId) Future<bool>
getAdapterState() Future<BleAdapterState>
isDeviceConnected(BleRemoteId remoteId) bool
isSupported() Future<bool>
mtuNow(BleRemoteId remoteId) int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
platformName(BleRemoteId remoteId) String
requestMtu({required String remoteId, required int mtu}) Future<bool>
scan({Duration? timeout}) Stream<BleScanResult>
servicesForDevice(BleRemoteId remoteId) List<BleService>
toString() String
A string representation of this object.
inherited
writeCharacteristic({required String remoteId, required String serviceUuid, required String characteristicUuid, required int instanceId, required List<int> value, String? primaryServiceUuid, bool withoutResponse}) Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance BlePlatform
getter/setter pair